==> e107-0.7.20.tbz: www/e107/e107_plugins/log/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/log/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("PAGE_NAME", "Statistics");

define("ADSTAT_L1", "This plugin will log all visits to your site, and build detailed statistic screens based on the information gathered.");
define("ADSTAT_L2", "The statistics logger has been successfully installed. To convert your existing stats to the new system, please <a href='".e_PLUGIN."log/update_routine.php'>click here to run update routine</a>.");
define("ADSTAT_L3", "Statistic Logging");
define("ADSTAT_L4", "You do not have permission to view this page.");
define("ADSTAT_L5", "The features on this page have been disabled.");
define("ADSTAT_L6", "Site Statistics");
define("ADSTAT_L7", "Statistics for this type is not being gathered.");
define("ADSTAT_L8", "Today's Stats");
define("ADSTAT_L9", "All-time Stats");
define("ADSTAT_L10", "Daily Stats");
define("ADSTAT_L11", "Monthly Stats");
define("ADSTAT_L12", "Browser Stats");
define("ADSTAT_L13", "Operating System Stats");
define("ADSTAT_L14", "Domain Stats");
define("ADSTAT_L15", "Screen Resolution / Color Depth Stats");
define("ADSTAT_L16", "Referral Stats");
define("ADSTAT_L17", "Search String Stats");
define("ADSTAT_L18", "Recent Visitors");
define("ADSTAT_L19", "Page");
define("ADSTAT_L20", "Visits Today");
define("ADSTAT_L21", "Total");
define("ADSTAT_L22", "Unique");
define("ADSTAT_L23", "Total Visits");
define("ADSTAT_L24", "Total Unique Visits");
define("ADSTAT_L25", "No statistics yet.");
define("ADSTAT_L26", "Browser");
define("ADSTAT_L27", "Operating System");
define("ADSTAT_L28", "Countries / Domains");
define("ADSTAT_L29", "Screen Resolution");
define("ADSTAT_L30", "Site Referrals");
define("ADSTAT_L31", "Search Engine Query Strings");
define("ADSTAT_L32", "Referred from");
define("ADSTAT_L33", "Visits in last");
define("ADSTAT_L34", "Visits");
define("ADSTAT_L35", "Unique visits in last");
define("ADSTAT_L36", "days by page");
define("ADSTAT_L37", "Visits by month");
define("ADSTAT_L38", "Unique visits by month");
define("ADSTAT_L39", "remove this entry");
define("ADSTAT_L40", "days");
define("ADSTAT_L41", "Error");
define("ADSTAT_L42", "No monthly stats yet.");

define("ADSTAT_L43", "Today's page errors");
define("ADSTAT_L44", "All-time page errors");
define("ADSTAT_L45", "Stats deleted for: ");
define("ADSTAT_L46", "Note: any stats for today will not be deleted");
define("ADSTAT_L47", "No stats found for: ");
define("ADSTAT_L48", "");
define("ADSTAT_L49", "");
define("ADSTAT_L50", "");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/log/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/log/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("PAGE_NAME", "Statistics");

define("ADSTAT_L1", "This plugin will log all visits to your site, and build detailed statistic screens based on the information gathered.");
define("ADSTAT_L2", "The statistics logger has been successfully installed. To convert your existing stats to the new system, please <a href='".e_PLUGIN."log/update_routine.php'>click here to run update routine</a>.");
define("ADSTAT_L3", "Statistic Logging");
define("ADSTAT_L4", "You do not have permission to view this page.");
define("ADSTAT_L5", "The features on this page have been disabled.");
define("ADSTAT_L6", "Site Statistics");
define("ADSTAT_L7", "Statistics for this type is not being gathered.");
define("ADSTAT_L8", "Today's Stats");
define("ADSTAT_L9", "All-time Stats");
define("ADSTAT_L10", "Daily Stats");
define("ADSTAT_L11", "Monthly Stats");
define("ADSTAT_L12", "Browser Stats");
define("ADSTAT_L13", "Operating System Stats");
define("ADSTAT_L14", "Domain Stats");
define("ADSTAT_L15", "Screen Resolution / Color Depth Stats");
define("ADSTAT_L16", "Referral Stats");
define("ADSTAT_L17", "Search String Stats");
define("ADSTAT_L18", "Recent Visitors");
define("ADSTAT_L19", "Page");
define("ADSTAT_L20", "Visits Today");
define("ADSTAT_L21", "Total");
define("ADSTAT_L22", "Unique");
define("ADSTAT_L23", "Total Visits");
define("ADSTAT_L24", "Total Unique Visits");
define("ADSTAT_L25", "No statistics yet.");
define("ADSTAT_L26", "Browser");
define("ADSTAT_L27", "Operating System");
define("ADSTAT_L28", "Countries / Domains");
define("ADSTAT_L29", "Screen Resolution");
define("ADSTAT_L30", "Site Referrals");
define("ADSTAT_L31", "Search Engine Query Strings");
define("ADSTAT_L32", "Referred from");
define("ADSTAT_L33", "Visits in last");
define("ADSTAT_L34", "Visits");
define("ADSTAT_L35", "Unique visits in last");
define("ADSTAT_L36", "days by page");
define("ADSTAT_L37", "Visits by month");
define("ADSTAT_L38", "Unique visits by month");
define("ADSTAT_L39", "remove this entry");
define("ADSTAT_L40", "days");
define("ADSTAT_L41", "Error");
define("ADSTAT_L42", "No monthly stats yet.");

define("ADSTAT_L43", "Today's page errors");
define("ADSTAT_L44", "All-time page errors");
define("ADSTAT_L45", "Stats deleted for: ");
define("ADSTAT_L46", "Note: any stats for today will not be deleted");
define("ADSTAT_L47", "No stats found for: ");
define("ADSTAT_L48", "");
define("ADSTAT_L49", "");
define("ADSTAT_L50", "");

?>
